==> com.liferay.change.tracking.service-3.0.113-sources.jar: com/liferay/change/tracking/internal/search/spi/model/index/contributor/CTRemoteModelIndexerWriterContributor.java <==
/**
 * SPDX-FileCopyrightText: (c) 2000 Liferay, Inc. https://liferay.com
 * SPDX-License-Identifier: LGPL-2.1-or-later OR LicenseRef-Liferay-DXP-EULA-2.0.0-2023-06
 */

package com.liferay.change.tracking.internal.search.spi.model.index.contributor;

import com.liferay.change.tracking.model.CTRemote;
import com.liferay.change.tracking.service.CTRemoteLocalService;
import com.liferay.portal.search.batch.BatchIndexingActionable;
import com.liferay.portal.search.batch.DynamicQueryBatchIndexingActionableFactory;
import com.liferay.portal.search.spi.model.index.contributor.ModelIndexerWriterContributor;
import com.liferay.portal.search.spi.model.index.contributor.helper.ModelIndexerWriterDocumentHelper;

/**
 * @author David Truong
 */
public class CTRemoteModelIndexerWriterContributor
	implements ModelIndexerWriterContributor<CTRemote> {

	public CTRemoteModelIndexerWriterContributor(
		CTRemoteLocalService ctRemoteLocalService,
		DynamicQueryBatchIndexingActionableFactory
			dynamicQueryBatchIndexingActionableFactory) {

		_ctRemoteLocalService = ctRemoteLocalService;
		_dynamicQueryBatchIndexingActionableFactory =
			dynamicQueryBatchIndexingActionableFactory;
	}

	@Override
	public void customize(
		BatchIndexingActionable batchIndexingActionable,
		ModelIndexerWriterDocumentHelper modelIndexerWriterDocumentHelper) {

		batchIndexingActionable.setPerformActionMethod(
			(CTRemote ctRemote) -> batchIndexingActionable.addDocuments(
				modelIndexerWriterDocumentHelper.getDocument(ctRemote)));
	}

	@Override
	public BatchIndexingActionable getBatchIndexingActionable() {
		return _dynamicQueryBatchIndexingActionableFactory.
			getBatchIndexingActionable(
				_ctRemoteLocalService.getIndexableActionableDynamicQuery());
	}

	@Override
	public long getCompanyId(CTRemote ctRemote) {
		return ctRemote.getCompanyId();
	}

	private final CTRemoteLocalService _ctRemoteLocalService;
	private final DynamicQueryBatchIndexingActionableFactory
		_dynamicQueryBatchIndexingActionableFactory;

}

==> com.liferay.change.tracking.service-3.0.116-sources.jar: com/liferay/change/tracking/internal/search/spi/model/index/contributor/CTRemoteModelIndexerWriterContributor.java <==
/**
 * SPDX-FileCopyrightText: (c) 2000 Liferay, Inc. https://liferay.com
 * SPDX-License-Identifier: LGPL-2.1-or-later OR LicenseRef-Liferay-DXP-EULA-2.0.0-2023-06
 */

package com.liferay.change.tracking.internal.search.spi.model.index.contributor;

import com.liferay.change.tracking.model.CTRemote;
import com.liferay.change.tracking.service.CTRemoteLocalService;
import com.liferay.petra.string.StringBundler;
import com.liferay.portal.kernel.change.tracking.CTCollectionThreadLocal;
import com.liferay.portal.kernel.dao.orm.IndexableActionableDynamicQuery;
import com.liferay.portal.kernel.dao.orm.RestrictionsFactoryUtil;
import com.liferay.portal.kernel.log.Log;
import com.liferay.portal.kernel.log.LogFactoryUtil;
import com.liferay.portal.search.batch.BatchIndexingActionable;
import com.liferay.portal.search.batch.DynamicQueryBatchIndexingActionableFactory;
import com.liferay.portal.search.spi.model.index.contributor.ModelIndexerWriterContributor;
import com.liferay.portal.search.spi.model.index.contributor.helper.ModelIndexerWriterDocumentHelper;

/**
 * @author David Truong
 */
public class CTRemoteModelIndexerWriterContributor
	implements ModelIndexerWriterContributor<CTRemote> {

	public CTRemoteModelIndexerWriterContributor(
		CTRemoteLocalService ctRemoteLocalService,
		DynamicQueryBatchIndexingActionableFactory
			dynamicQueryBatchIndexingActionableFactory) {

		_ctRemoteLocalService = ctRemoteLocalService;
		_dynamicQueryBatchIndexingActionableFactory =
			dynamicQueryBatchIndexingActionableFactory;
	}

	@Override
	public void customize(
		BatchIndexingActionable batchIndexingActionable,
		ModelIndexerWriterDocumentHelper modelIndexerWriterDocumentHelper) {

		batchIndexingActionable.setPerformActionMethod(
			(CTRemote ctRemote) -> batchIndexingActionable.addDocuments(
				modelIndexerWriterDocumentHelper.getDocument(ctRemote)));
	}

	@Override
	public BatchIndexingActionable getBatchIndexingActionable() {
		IndexableActionableDynamicQuery indexableActionableDynamicQuery =
			_ctRemoteLocalService.getIndexableActionableDynamicQuery();

		if (!CTCollectionThreadLocal.isProductionMode()) {
			if (_log.isDebugEnabled()) {
				_log.debug(
					StringBundler.concat(
						"Restricting indexable results of ",
						CTRemote.class.getName(), " because this can only be ",
						"performed in production mode"));
			}

			indexableActionableDynamicQuery.setAddCriteriaMethod(
				dynamicQuery -> dynamicQuery.add(
					RestrictionsFactoryUtil.eq("ctCollectionId", -1L)));
		}

		return _dynamicQueryBatchIndexingActionableFactory.
			getBatchIndexingActionable(indexableActionableDynamicQuery);
	}

	@Override
	public long getCompanyId(CTRemote ctRemote) {
		return ctRemote.getCompanyId();
	}

	private static final Log _log = LogFactoryUtil.getLog(
		CTRemoteModelIndexerWriterContributor.class);

	private final CTRemoteLocalService _ctRemoteLocalService;
	private final DynamicQueryBatchIndexingActionableFactory
		_dynamicQueryBatchIndexingActionableFactory;

}
